@@ -1,6 +1,7 @@
 from collections import OrderedDict
 
 from django import forms
+from django.utils.functional import cached_property
 from django.utils.translation import ugettext_lazy as _
 
 from . import app_settings
@@ -14,20 +15,41 @@ class BaseReportForm(object):
 
     def get_filters(self):
         """
-        Get the foreign key filters for report queryset,
+        Get the foreign key filters for report queryset, excluding crosstab ids, handled by `get_crosstab_ids()`
         :return: a dicttionary of filters to be used with QuerySet.filter(**returned_value)
         """
-        # todo: implement cross tab support
         _values = {}
         if self.is_valid():
             for key, field in self.foreign_keys.items():
-                if key in self.cleaned_data:
+                if key in self.cleaned_data and not key == self.crosstab_key_name:
                     val = self.cleaned_data[key]
                     if val:
                         val = [x for x in val.values_list('pk', flat=True)]
                         _values['%s__in' % key] = val
             return None, _values
 
+    @cached_property
+    def crosstab_key_name(self):
+        """
+        return the actual foreignkey field name by simply adding an '_id' at the end.
+        This is hook is to customize this naieve approach.
+        :return: key: a string that should be in self.cleaned_data
+        """
+        return f'{self.crosstab_model}_id'
+
+    def get_crosstab_ids(self):
+        """
+        Get the crosstab ids so they can be sent to the report generator.
+        :return: 
+        """
+        if self.crosstab_model:
+            qs = self.cleaned_data.get(self.crosstab_key_name)
+            return [x for x in qs.values_list('pk', flat=True)]
+        return []
+
+    def get_crosstab_compute_reminder(self):
+        return self.cleaned_data.get('crosstab_compute_reminder', True)
+
     def get_crispy_helper(self, foreign_keys_map=None, crosstab_model=None, **kwargs):
         from crispy_forms.helper import FormHelper
         from crispy_forms.layout import Column, Layout, Div, Row, Field
@@ -71,7 +93,8 @@ def _default_foreign_key_widget(f_field):
             'required': False, }
 
 
-def report_form_factory(model, fkeys_filter_func=None, foreign_key_widget_func=None, **kwargs):
+def report_form_factory(model, fkeys_filter_func=None, foreign_key_widget_func=None, crosstab_model=None,
+                        display_compute_reminder=True, **kwargs):
     foreign_key_widget_func = foreign_key_widget_func or _default_foreign_key_widget
     fkeys_filter_func = fkeys_filter_func or (lambda x: x)
 
@@ -100,9 +123,15 @@ def report_form_factory(model, fkeys_filter_func=None, foreign_key_widget_func=N
         fields[name] = f_field.formfield(
             **foreign_key_widget_func(f_field))
 
+    if crosstab_model and display_compute_reminder:
+        fields['crosstab_compute_reminder'] = forms.BooleanField(required=False,
+                                                                 label=_('display the crosstab reminder'),
+                                                                 initial=True)
+
     new_form = type('ReportForm', (BaseReportForm, forms.BaseForm,),
                     {"base_fields": fields,
                      '_fkeys': fkeys_list,
                      'foreign_keys': fkeys_map,
+                     'crosstab_model': crosstab_model
                      })
     return new_form
